import os
from bs4 import BeautifulSoup

base_dir = os.path.abspath(os.path.dirname(__file__))
log_path = os.path.join(base_dir, "log_favicon_patch.txt")

FAVICON_TAGS = '''
<link href="favicon.ico" rel="icon" type="image/x-icon"/>
<link href="favicon.png" rel="alternate icon" type="image/png"/>
'''
def log(message, log_file):
    print(message)
    log_file.write(message + '\n')

def patch_html_file(file_path, log_file):
    try:
        with open(file_path, 'r', encoding='utf-8') as file:
            content = file.read()

        soup = BeautifulSoup(content, 'html.parser')
        modified = False
        head_tag = soup.head
        if head_tag and not soup.head.find_all("link", href="favicon.ico"):
            favicon_soup = BeautifulSoup(FAVICON_TAGS, 'html.parser')
            for tag in favicon_soup.find_all():
                head_tag.append(tag)
            modified = True
            log(f"[+FAVICON] Inserito favicon in: {file_path}", log_file)
        else:
            log(f"[=FAVICON] Già presente o <head> mancante: {file_path}", log_file)
        html_tag = soup.find('html')
        if html_tag and html_tag.get('lang') == 'en':
            html_tag['lang'] = 'it'
            modified = True
            log(f"[+LANG] Sostituito lang='en' in lang='it': {file_path}", log_file)
        else:
            log(f"[=LANG] lang='it' già presente o assente: {file_path}", log_file)

        if modified:
            with open(file_path, 'w', encoding='utf-8') as file:
                file.write(str(soup))
            log(f"[✔️ OK] File aggiornato: {file_path}", log_file)
        else:
            log(f"[SKIP] Nessuna modifica richiesta: {file_path}", log_file)

    except Exception as e:
        log(f"[❌ ERROR] Errore in {file_path}: {e}", log_file)

def scan_and_patch(current_dir):
    count = 0
    with open(log_path, 'w', encoding='utf-8') as log_file:
        for root, dirs, files in os.walk(current_dir):
            for filename in files:
                if filename.endswith('.html'):
                    file_path = os.path.join(root, filename)
                    patch_html_file(file_path, log_file)
                    count += 1
        log(f"\n🏁 Completato. Totale file analizzati: {count}", log_file)

if __name__ == '__main__':
    scan_and_patch(base_dir)
