import os
from bs4 import BeautifulSoup, NavigableString
from deep_translator import GoogleTranslator

# Directory principale dove si trova lo script
base_dir = os.path.abspath(os.path.dirname(__file__))

def batch_translate_texts(texts, target='it'):
    try:
        translator = GoogleTranslator(source='en', target=target)
        translated = translator.translate_batch(texts)
        return translated
    except Exception as e:
        print(f"⚠️ Errore nella traduzione batch: {e}")
        return texts  # fallback: restituisci i testi originali

def translate_node_text_batch(node, target_language='it'):
    if node.name in ['script', 'style']:
        return

    texts_to_translate = []
    text_nodes = []

    # Raccoglie i testi da tradurre
    for child in node.descendants:
        if isinstance(child, NavigableString):
            original = str(child).strip()
            if original:
                texts_to_translate.append(original)
                text_nodes.append(child)

    # Traduce in batch
    if texts_to_translate:
        translated_texts = batch_translate_texts(texts_to_translate, target_language)
        for original_node, translated in zip(text_nodes, translated_texts):
            try:
                original_node.replace_with(translated)
            except Exception as e:
                print(f"⚠️ Errore nel rimpiazzare '{str(original_node)[:30]}...': {e}")

def translate_html(file_path, target_language='it'):
    try:
        with open(file_path, 'r', encoding='utf-8') as file:
            soup = BeautifulSoup(file, 'html.parser')

        translate_node_text_batch(soup, target_language)

        with open(file_path, 'w', encoding='utf-8') as out_file:
            out_file.write(str(soup))

        print(f"✅ Tradotto: {file_path}")

    except Exception as e:
        print(f"❌ Errore con il file {file_path}: {e}")

def scan_and_translate(current_dir):
    html_files = []
    for root, dirs, files in os.walk(current_dir):
        for filename in files:
            if filename.endswith('.html'):
                file_path = os.path.join(root, filename)
                html_files.append(file_path)

    total_files = len(html_files)
    print(f"📊 Totale file da tradurre: {total_files}")

    for idx, file_path in enumerate(html_files, start=1):
        translate_html(file_path)
        print(f"📂 Tradotti {idx}/{total_files} file, {total_files - idx} rimanenti...")

if __name__ == '__main__':
    scan_and_translate(base_dir)
    print("\n✅ Traduzione completata. I file .html sono stati aggiornati senza danneggiare l'HTML.")
