import os
from bs4 import BeautifulSoup, NavigableString
from deep_translator import GoogleTranslator
from concurrent.futures import ThreadPoolExecutor, as_completed

# Directory principale dove si trova lo script
base_dir = os.path.abspath(os.path.dirname(__file__))

def translate_text(text, target='it'):
    text = text.strip()
    if len(text) < 2:
        return text  # ignora testi troppo brevi o vuoti

    try:
        translated = GoogleTranslator(source='en', target=target).translate(text)
        return translated if translated else text
    except Exception as e:
        print(f"⚠️ Errore nella traduzione di: '{text[:30]}...': {e}")
        return text

def translate_node_text(node, target_language='it'):
    if node.name in ['script', 'style']:
        return

    for child in node.contents:
        if isinstance(child, NavigableString):
            original = str(child).strip()
            if original:
                translated = translate_text(original, target_language)
                try:
                    child.replace_with(translated)
                except Exception as e:
                    print(f"⚠️ Errore nel rimpiazzare '{original[:30]}...': {e}")
        elif child.name:
            translate_node_text(child, target_language)

def translate_html(file_path, target_language='it'):
    try:
        with open(file_path, 'r', encoding='utf-8') as file:
            soup = BeautifulSoup(file, 'html.parser')

        translate_node_text(soup, target_language)

        with open(file_path, 'w', encoding='utf-8') as out_file:
            out_file.write(str(soup))

        print(f"✅ Tradotto: {file_path}")

    except Exception as e:
        print(f"❌ Errore con il file {file_path}: {e}")

def scan_and_translate(current_dir):
    html_files = []
    for root, dirs, files in os.walk(current_dir):
        for filename in files:
            if filename.endswith('.html'):
                file_path = os.path.join(root, filename)
                html_files.append(file_path)

    total_files = len(html_files)
    print(f"📊 Totale file da tradurre: {total_files}")

    completed = 0
    with ThreadPoolExecutor(max_workers=4) as executor:
        futures = {executor.submit(translate_html, path): path for path in html_files}
        for future in as_completed(futures):
            completed += 1
            print(f"📂 Tradotti {completed}/{total_files} file, {total_files - completed} rimanenti...")

if __name__ == '__main__':
    scan_and_translate(base_dir)
    print("\n✅ Traduzione completata. I file .html sono stati aggiornati senza danneggiare l'HTML.")
